@@ -2,7 +2,7 @@
 // GrB_BinaryOp_free: free a binary operator
 //------------------------------------------------------------------------------
 
-// SuiteSparse:GraphBLAS, Timothy A. Davis, (c) 2017, All Rights Reserved.
+// SuiteSparse:GraphBLAS, Timothy A. Davis, (c) 2017-2018, All Rights Reserved.
 // http://suitesparse.com   See GraphBLAS/Doc/License.txt for license.
 
 //------------------------------------------------------------------------------
@@ -24,7 +24,8 @@ GrB_Info GrB_BinaryOp_free          // free a user-created binary operator
             if (op->magic == MAGIC)
             {
                 op->magic = FREED ;         // to help detect dangling pointers
-                GB_FREE_MEMORY (*binaryop, 1, sizeof (GB_BinaryOp_opaque)) ;
+                GB_FREE_MEMORY (*binaryop, 1,
+                    sizeof (struct GB_BinaryOp_opaque)) ;
             }
             (*binaryop) = NULL ;
         }
